
This is a multiselect for `yafowil <http://pypi.python.org/pypi/yafowil>`_

It is based on the jQuery `multi-select https://github.com/lou/multi-select`_
plugin.

- `Documentation <http://docs.yafowil.info/en/latest/blueprints.html#multiselect>`_
- `DEMO - see it Live <http://demo.yafowil.info/++widget++yafowil.widget.multiselect/index.html>`_


Source Code
===========

The sources are in a GIT DVCS with its main branches at
`github <http://github.com/bluedynamics/yafowil.widget.multiselect>`_.

We'd be happy to see many forks and pull-requests to make YAFOWIL even better.


Contributors
============

- Johannes Raggam <johannes [at] raggam [dot] co [dot] at>
